@@ -23,7 +23,7 @@ fn quick_sort_custom_order_benchmark(b: &mut Bencher) {
     for _ in 1..10000 {
         numbers.push(rand::random::<u32>());
     }
-    b.iter(|| quick_sort::sort_by(numbers.as_mut_slice(), &|a, b| a > b));
+    b.iter(|| quick_sort::sort_by(numbers.as_mut_slice(), &|a, b| b.cmp(a)));
 }
 
 #[bench]
